pub struct AddRateV1BodyMinimumConfig {
pub minimum: f64,
}Expand description
Only set for TIERED_PERCENTAGE or PERCENTAGE rate_type. Any commit-specific overrides will not apply if there is a minimum set on the rate/applied override.
JSON schema
{
"description": "Only set for TIERED_PERCENTAGE or PERCENTAGE rate_type.
Any commit-specific overrides will not apply if there is a minimum set
on the rate/applied override.",
"type": "object",
"required": [
"minimum"
],
"properties": {
"minimum": {
"type": "number"
}
},
"x-mint": {
"groups": [
"ff:support-charge-ga"
]
},
"x-stainless-skip": true
}Fields
minimum: f64Trait Implementations
Sourceimpl Clone for AddRateV1BodyMinimumConfig
impl Clone for AddRateV1BodyMinimumConfig
Sourcefn clone(&self) -> AddRateV1BodyMinimumConfig
fn clone(&self) -> AddRateV1BodyMinimumConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddRateV1BodyMinimumConfig
impl Debug for AddRateV1BodyMinimumConfig
Sourceimpl<'de> Deserialize<'de> for AddRateV1BodyMinimumConfig
impl<'de> Deserialize<'de> for AddRateV1BodyMinimumConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more