pub struct CreateAlertV1BodyAlertSpecifiersItem {
pub custom_field_filters: Vec<CreateAlertV1BodyAlertSpecifiersItemCustomFieldFiltersItem>,
pub exclude: Vec<CreateAlertV1BodyAlertSpecifiersItemExcludeItem>,
}Expand description
CreateAlertV1BodyAlertSpecifiersItem
JSON schema
{
"type": "object",
"properties": {
"custom_field_filters": {
"description": "A list of custom field filters for notification
types that support advanced filtering",
"type": "array",
"items": {
"type": "object",
"required": [
"entity",
"key"
],
"properties": {
"entity": {
"type": "string",
"enum": [
"Contract",
"Commit",
"ContractCredit",
"ContractCreditOrCommit"
],
"x-mint-enum": {
"ContractCreditOrCommit": [
"ff:alert-specifiers-enabled"
]
}
},
"key": {
"type": "string"
},
"value": {
"type": "string"
}
}
}
},
"exclude": {
"description": "If provided, the specifier will not apply to
balances that matches the inclusion criteria and any of the excluding
values.",
"type": "array",
"items": {
"type": "object",
"properties": {
"custom_field_filters": {
"description": "A list of custom field filters for
notification types that support advanced filtering",
"type": "array",
"items": {
"type": "object",
"required": [
"entity",
"key",
"value"
],
"properties": {
"entity": {
"type": "string",
"enum": [
"Contract",
"Commit",
"ContractCredit",
"ContractCreditOrCommit"
],
"x-mint-enum": {
"ContractCreditOrCommit": [
"ff:alert-specifiers-enabled"
]
}
},
"key": {
"type": "string"
},
"value": {
"type": "string"
}
}
}
}
}
}
}
}
}Fields
custom_field_filters: Vec<CreateAlertV1BodyAlertSpecifiersItemCustomFieldFiltersItem>A list of custom field filters for notification types that support advanced filtering
exclude: Vec<CreateAlertV1BodyAlertSpecifiersItemExcludeItem>If provided, the specifier will not apply to balances that matches the inclusion criteria and any of the excluding values.