CreateCustomerCommitV1BodyInvoiceScheduleRecurringSchedule

Struct CreateCustomerCommitV1BodyInvoiceScheduleRecurringSchedule 

pub struct CreateCustomerCommitV1BodyInvoiceScheduleRecurringSchedule {
    pub amount: Option<f64>,
    pub amount_distribution: String,
    pub ending_before: DateTime<Utc>,
    pub frequency: String,
    pub quantity: Option<f64>,
    pub starting_at: DateTime<Utc>,
    pub unit_price: Option<f64>,
}
Enter the unit price and quantity for the charge or instead only send the amount. If amount is sent, the unit price is assumed to be the amount and quantity is inferred to be 1.

JSON schema
{
 "description": "Enter the unit price and quantity for the charge or
instead only send the amount. If amount is sent, the unit price is
assumed to be the amount and quantity is inferred to be 1.",
 "type": "object",
 "required": [
   "amount_distribution",
   "ending_before",
   "frequency",
   "starting_at"
 ],
 "properties": {
   "amount": {
     "description": "Amount for the charge. Can be provided instead of
unit_price and quantity. If amount is sent, the unit_price is assumed to
be the amount and quantity is inferred to be 1.",
     "type": "number"
   },
   "amount_distribution": {
     "type": "string"
   },
   "ending_before": {
     "description": "RFC 3339 timestamp (exclusive).",
     "type": "string",
     "format": "date-time"
   },
   "frequency": {
     "type": "string"
   },
   "quantity": {
     "description": "Quantity for the charge. Will be multiplied by
unit_price to determine the amount and must be specified with
unit_price. If specified amount cannot be provided.",
     "type": "number"
   },
   "starting_at": {
     "description": "RFC 3339 timestamp (inclusive).",
     "type": "string",
     "format": "date-time"
   },
   "unit_price": {
     "description": "Unit price for the charge. Will be multiplied by
quantity to determine the amount and must be specified with quantity. If
specified amount cannot be provided.",
     "type": "number"
   }
 }
}

Fields

amount: Option<f64>

Amount for the charge. Can be provided instead of unit_price and quantity. If amount is sent, the unit_price is assumed to be the amount and quantity is inferred to be 1.

amount_distribution: Stringending_before: DateTime<Utc>

RFC 3339 timestamp (exclusive).

frequency: Stringquantity: Option<f64>

Quantity for the charge. Will be multiplied by unit_price to determine the amount and must be specified with unit_price. If specified amount cannot be provided.

starting_at: DateTime<Utc>

RFC 3339 timestamp (inclusive).

unit_price: Option<f64>

Unit price for the charge. Will be multiplied by quantity to determine the amount and must be specified with quantity. If specified amount cannot be provided.