pub struct CreateCustomerCommitV1BodySpecifiersItem {
pub exclude: Vec<CreateCustomerCommitV1BodySpecifiersItemExcludeItem>,
pub presentation_group_values: HashMap<String, String>,
pub pricing_group_values: HashMap<String, String>,
pub product_id: Option<Uuid>,
pub product_tags: Vec<String>,
}Expand description
CreateCustomerCommitV1BodySpecifiersItem
JSON schema
{
"type": "object",
"properties": {
"exclude": {
"description": "If provided, the specifier will not apply to
product usage that matches the inclusion criteria and any of the
excluding values.",
"type": "array",
"items": {
"type": "object",
"properties": {
"product_tags": {
"description": "If provided, the specifier will not apply to
products with all the specified tags.",
"type": "array",
"items": {
"type": "string"
}
}
}
},
"x-mint": {
"groups": [
"ff:exclude-specifiers-ga"
]
},
"x-stainless-skip": true
},
"presentation_group_values": {
"description": "If provided, the specifier will apply to product
usage with these set of presentation group values.",
"type": "object",
"additionalProperties": {
"type": "string"
}
},
"pricing_group_values": {
"description": "If provided, the specifier will apply to product
usage with these set of pricing group values.",
"type": "object",
"additionalProperties": {
"type": "string"
}
},
"product_id": {
"description": "If provided, the specifier will only apply to the
product with the specified ID.",
"type": "string",
"format": "uuid"
},
"product_tags": {
"description": "If provided, the specifier will only apply to
products with all the specified tags.",
"type": "array",
"items": {
"type": "string"
}
}
}
}Fields
exclude: Vec<CreateCustomerCommitV1BodySpecifiersItemExcludeItem>If provided, the specifier will not apply to product usage that matches the inclusion criteria and any of the excluding values.
presentation_group_values: HashMap<String, String>If provided, the specifier will apply to product usage with these set of presentation group values.
pricing_group_values: HashMap<String, String>If provided, the specifier will apply to product usage with these set of pricing group values.
product_id: Option<Uuid>If provided, the specifier will only apply to the product with the specified ID.
If provided, the specifier will only apply to products with all the specified tags.