pub struct CreateNotificationConfigV2ResponseData {
pub archived_at: Option<DateTime<Utc>>,
pub created_at: DateTime<Utc>,
pub created_by: String,
pub environment_type: String,
pub id: Uuid,
pub name: String,
pub policy: CreateNotificationConfigV2ResponseDataPolicy,
pub type_: String,
}Expand description
CreateNotificationConfigV2ResponseData
JSON schema
{
"type": "object",
"required": [
"archived_at",
"created_at",
"created_by",
"environment_type",
"id",
"name",
"policy",
"type"
],
"properties": {
"archived_at": {
"description": "When this notification configuration was archived",
"type": [
"string",
"null"
],
"format": "date-time"
},
"created_at": {
"description": "RFC 3339 timestamp when this notification
configuration was created.\n",
"type": "string",
"format": "date-time"
},
"created_by": {
"description": "Who created this notification configuration",
"type": "string"
},
"environment_type": {
"description": "The environment type where this notification
configuration was created.\n",
"type": "string"
},
"id": {
"description": "ID for this offset notification configuration",
"type": "string",
"format": "uuid"
},
"name": {
"description": "The name for this offset notification
configuration.\n",
"type": "string"
},
"policy": {
"type": "object",
"required": [
"offset",
"type"
],
"properties": {
"offset": {
"description": "ISO-8601 duration string indicating how much
time before or after the base event this notification should be sent.
Positive values indicate notifications after the event, negative values
indicate notifications before the event. Examples: \"P1D\" (1 day
after), \"-PT2H\" (2 hours before)\n",
"examples": [
"P1D"
],
"type": "string"
},
"type": {
"description": "The type of lifecycle event that this offset is
based on.\n",
"type": "string"
}
}
},
"type": {
"description": "Indicates this is an offset lifecycle event
notification",
"type": "string"
}
}
}Fields
archived_at: Option<DateTime<Utc>>When this notification configuration was archived
created_at: DateTime<Utc>RFC 3339 timestamp when this notification configuration was created.
created_by: StringWho created this notification configuration
environment_type: StringThe environment type where this notification configuration was created.
id: UuidID for this offset notification configuration
name: StringThe name for this offset notification configuration.
policy: CreateNotificationConfigV2ResponseDataPolicytype_: StringIndicates this is an offset lifecycle event notification