CreateNotificationConfigV2ResponseDataPolicy

Struct CreateNotificationConfigV2ResponseDataPolicy 

pub struct CreateNotificationConfigV2ResponseDataPolicy {
    pub offset: String,
    pub type_: String,
}
CreateNotificationConfigV2ResponseDataPolicy

JSON schema
{
 "type": "object",
 "required": [
   "offset",
   "type"
 ],
 "properties": {
   "offset": {
     "description": "ISO-8601 duration string indicating how much time
before or after the base event this notification should be sent.
Positive values indicate notifications after the event, negative values
indicate notifications before the event. Examples: \"P1D\" (1 day
after), \"-PT2H\" (2 hours before)\n",
     "examples": [
       "P1D"
     ],
     "type": "string"
   },
   "type": {
     "description": "The type of lifecycle event that this offset is
based on.\n",
     "type": "string"
   }
 }
}

Fields

offset: String

ISO-8601 duration string indicating how much time before or after the base event this notification should be sent. Positive values indicate notifications after the event, negative values indicate notifications before the event. Examples: “P1D” (1 day after), “-PT2H” (2 hours before)

type_: String

The type of lifecycle event that this offset is based on.