pub struct CreateNotificationConfigV2Body {
pub name: String,
pub policy: CreateNotificationConfigV2BodyPolicy,
pub uniqueness_key: Option<CreateNotificationConfigV2BodyUniquenessKey>,
}Expand description
CreateNotificationConfigV2Body
JSON schema
{
"type": "object",
"required": [
"name",
"policy"
],
"properties": {
"name": {
"description": "The name for this offset notification
configuration.\n",
"type": "string"
},
"policy": {
"description": "The offset lifecycle event policy that defines when
and how this notification should be triggered. The lifecycle event type
is inferred from the policy.type field.\n",
"type": "object",
"required": [
"offset",
"type"
],
"properties": {
"offset": {
"description": "ISO-8601 duration string indicating how much
time before or after the base event this notification should be sent.
Positive values indicate notifications after the event, negative values
indicate notifications before the event. Examples: \"P1D\" (1 day
after), \"-PT2H\" (2 hours before)\n",
"examples": [
"P1D"
],
"type": "string"
},
"type": {
"description": "The type of lifecycle event that this offset is
based on.\n",
"type": "string"
}
}
},
"uniqueness_key": {
"description": "Optional uniqueness key to prevent duplicate
notification configurations.\n",
"type": "string",
"maxLength": 128,
"minLength": 1
}
}
}Fields
name: StringThe name for this offset notification configuration.
policy: CreateNotificationConfigV2BodyPolicyuniqueness_key: Option<CreateNotificationConfigV2BodyUniquenessKey>Optional uniqueness key to prevent duplicate notification configurations.