pub struct CreateRateCardV1Body {
pub aliases: Vec<CreateRateCardV1BodyAliasesItem>,
pub credit_type_conversions: Vec<CreateRateCardV1BodyCreditTypeConversionsItem>,
pub custom_fields: HashMap<String, String>,
pub description: Option<String>,
pub fiat_credit_type_id: Option<Uuid>,
pub name: String,
}Expand description
CreateRateCardV1Body
JSON schema
{
"type": "object",
"required": [
"name"
],
"properties": {
"aliases": {
"description": "Reference this alias when creating a contract. If
the same alias is assigned to multiple rate cards, it will reference the
rate card to which it was most recently assigned. It is not exposed to
end customers.",
"type": "array",
"items": {
"type": "object",
"required": [
"name"
],
"properties": {
"ending_before": {
"type": "string",
"format": "date-time"
},
"name": {
"type": "string"
},
"starting_at": {
"type": "string",
"format": "date-time"
}
}
}
},
"credit_type_conversions": {
"description": "Required when using custom pricing units in
rates.",
"type": "array",
"items": {
"type": "object",
"required": [
"custom_credit_type_id",
"fiat_per_custom_credit"
],
"properties": {
"custom_credit_type_id": {
"type": "string",
"format": "uuid"
},
"fiat_per_custom_credit": {
"type": "number"
}
}
}
},
"custom_fields": {
"description": "Custom fields to be added eg. { \"key1\":
\"value1\", \"key2\": \"value2\" }",
"type": "object",
"additionalProperties": {
"type": "string"
}
},
"description": {
"type": "string"
},
"fiat_credit_type_id": {
"description": "The Metronome ID of the credit type to associate
with the rate card, defaults to USD (cents) if not passed.",
"examples": [
"2714e483-4ff1-48e4-9e25-ac732e8f24f2"
],
"type": "string",
"format": "uuid"
},
"name": {
"description": "Used only in UI/API. It is not exposed to end
customers.",
"type": "string"
}
}
}Fields
aliases: Vec<CreateRateCardV1BodyAliasesItem>Reference this alias when creating a contract. If the same alias is assigned to multiple rate cards, it will reference the rate card to which it was most recently assigned. It is not exposed to end customers.
credit_type_conversions: Vec<CreateRateCardV1BodyCreditTypeConversionsItem>Required when using custom pricing units in rates.
custom_fields: HashMap<String, String>Custom fields to be added eg. { “key1”: “value1”, “key2”: “value2” }
description: Option<String>fiat_credit_type_id: Option<Uuid>The Metronome ID of the credit type to associate with the rate card, defaults to USD (cents) if not passed.
name: StringUsed only in UI/API. It is not exposed to end customers.